// SPDX-License-Identifier: MIT

#ifndef RGBDS_UTIL_HPP
#define RGBDS_UTIL_HPP

bool startsIdentifier(int c);
bool continuesIdentifier(int c);

char const *printChar(int c);

#endif // RGBDS_UTIL_HPP
